@@ -4,10 +4,9 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.003008';
+our $VERSION = '0.003009';
 
 use List::AllUtils qw( first max );
-use Memory::Stats;
 use Module::Pluggable::Object;
 use MooseX::Params::Validate qw( validated_list );
 use Parallel::ForkManager;
@@ -17,7 +16,7 @@ use Stepford::Plan;
 use Stepford::Runner::State;
 use Stepford::Types qw(
     ArrayOfClassPrefixes ArrayOfSteps Bool ClassName
-    HashRef Logger PositiveInt Step
+    HashRef Logger Maybe PositiveInt Step
 );
 use Try::Tiny;
 
@@ -51,11 +50,18 @@ has jobs => (
 
 has _memory_stats => (
     is      => 'ro',
-    isa     => 'Memory::Stats',
+    isa     => Maybe ['Memory::Stats'],
     default => sub {
-        my $s = Memory::Stats->new;
-        $s->start;
-        $s;
+        return try {
+            require Memory::Stats;
+            my $s = Memory::Stats->new;
+            $s->start;
+            $s;
+        }
+        catch {
+            undef;
+        }
+
     },
 );
 
@@ -251,6 +257,8 @@ sub _log_memory_usage {
     my $self       = shift;
     my $checkpoint = shift;
 
+    return unless $self->_memory_stats;
+
     $self->_memory_stats->checkpoint($checkpoint);
 
     # There's no way to get the total use so far without calling stop(), which
@@ -356,7 +364,7 @@ Stepford::Runner - Takes a set of steps and figures out what order to run them i
 
 =head1 VERSION
 
-version 0.003008
+version 0.003009
 
 =head1 SYNOPSIS
 
@@ -536,7 +544,7 @@ Dave Rolsky <drolsky@maxmind.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by MaxMind, Inc..
+This software is copyright (c) 2016 by MaxMind, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
