@@ -2,6 +2,7 @@ package Test1::Step::CreateA1;
 
 use strict;
 use warnings;
+use namespace::autoclean;
 
 use Stepford::Types qw( Dir File );
 use Time::HiRes qw( stat );
@@ -21,21 +22,24 @@ has a1_file => (
     is      => 'ro',
     isa     => File,
     lazy    => 1,
-    default => sub { $_[0]->tempdir()->file('a1') },
+    default => sub { $_[0]->tempdir->file('a1') },
 );
 
+## no critic (Variables::ProhibitPackageVars)
 our $RunCount = 0;
 
 sub run {
     my $self = shift;
 
-    return if -f $self->a1_file();
+    return if -f $self->a1_file;
 
-    $self->a1_file()->touch();
+    $self->a1_file->touch;
 }
 
 after run => sub { $RunCount++ };
 
-__PACKAGE__->meta()->make_immutable();
+sub run_count { $RunCount }
+
+__PACKAGE__->meta->make_immutable;
 
 1;
